@@ -2,7 +2,7 @@ package Test2::Plugin::ExitSummary;
 use strict;
 use warnings;
 
-our $VERSION = '0.000052';
+our $VERSION = '0.000058';
 
 use Test2::API qw/test2_add_callback_exit/;
 
@@ -27,7 +27,7 @@ sub summary {
         if $real;
 
     $ctx->diag("Did not follow plan: expected $plan, ran $count.")
-        if $plan && $plan =~ m/^\d+$/ && defined $count && $count != $plan;
+        if $plan && $plan =~ m/^[0-9]+$/ && defined $count && $count != $plan;
 }
 
 1;
